#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
from openeye import oegrid

grid = oegrid.OEScalarGrid(2, 2, 2, 0.0, 0.0, 0.0, 0.5)
grid.SetTitle("Simple Grid")

print("Title:", grid.GetTitle())

print("Mid: %12.6f %12.6f %12.6f" % grid.GetMid())

print("Dim: %6d %6d %6d" % grid.GetDim())

print("Spacing: %12.6f" % grid.GetSpacing())

print("Values:")
for iz in range(grid.GetZDim()):
    for iy in range(grid.GetYDim()):
        for ix in range(grid.GetXDim()):
            print("%-12.6e" % grid.GetValue(ix, iy, iz))
# @ </SNIPPET>
