#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
from openeye import oechem

mol = oechem.OEGraphMol()
oechem.OESmilesToMol(mol, "C/C=C/C[C@@](C)(N)O")

# @ <SNIPPET-CHIRAL-ATOM-LOOP1>
for atom in mol.GetAtoms(oechem.OEIsChiralAtom()):
    print(atom.GetIdx(), oechem.OEGetAtomicSymbol(atom.GetAtomicNum()))
# @ </SNIPPET-CHIRAL-ATOM-LOOP1>

# @ <SNIPPET-CHIRAL-ATOM-LOOP2>
for atom in mol.GetAtoms():
    if atom.IsChiral():
        print(atom.GetIdx(), oechem.OEGetAtomicSymbol(atom.GetAtomicNum()))
# @ </SNIPPET-CHIRAL-ATOM-LOOP2>

# @ <SNIPPET-CHIRAL-BOND-LOOP1>
for bond in mol.GetBonds(oechem.OEIsChiralBond()):
    print(bond.GetBgnIdx(), "=", bond.GetEndIdx())
# @ </SNIPPET-CHIRAL-BOND-LOOP1>

# @ <SNIPPET-CHIRAL-BOND-LOOP2>
for bond in mol.GetBonds():
    if bond.IsChiral():
        print(bond.GetBgnIdx(), "=", bond.GetEndIdx())
# @ </SNIPPET-CHIRAL-BOND-LOOP2>
# @ </SNIPPET>
